// Base requires
const { Client, GatewayIntentBits, Events } = require("discord.js")
const fs = require("fs")

// TOKEN is stored in the .env file (node --env-file=.env index.js)
const token = process.env.TOKEN

// Creating a client
const client = new Client({
    intents: [
        GatewayIntentBits.GuildMembers, 
        GatewayIntentBits.GuildMessages,
        GatewayIntentBits.MessageContent, 
        GatewayIntentBits.GuildVoiceStates, 
        GatewayIntentBits.DirectMessages,
        GatewayIntentBits.Guilds
    ]
    }
)

// Exporting the client for event and command files to use it
module.exports = {client: client, dir: __dirname}

// Requiring all the event files.
fs.readdir(`${__dirname}/events/`, (err, files) => {
    files.forEach(file => {
        if (!file.endsWith(".js")) {
            return
        }
        require(`${__dirname}/events/${file}`)
    })
})

// Command list
const commands = []

// Requiring the command files
fs.readdir(`${__dirname}/commands`, (err, files) => {
    files.forEach(file => {
        if (!file.endsWith("js")) {
            return
        }

        const commandList = require(`${__dirname}/commands/${file}`)

        commands.push(commandList)
    })
})

// Function to get the command with that name
function getCommand(commandName) {
    var command;
    commands.forEach(commandList => {
        commandList.forEach(commandArray => {
            if (commandArray.name == commandName) {
                command = commandArray
            } 
        })
    })
    return command;
}

// Parsing commands on message create
client.on("messageCreate", async (message) => {
    var content = message.content

    // Continue only if starts with the prefix
    if (!content.startsWith('!')) {
        return
    }

    // Need to remove the prefix after the check
    content = content.slice(1, content.length)

    // Splitting the message into command and args
    const parsed = content.split(" ")

    // Getting command name
    const command = parsed[0]

    // Removing command from the args
    const args = parsed.filter(value => {return value != command})

    // Actual command
    const realCommand = getCommand(command)

    // Only continue if command exists
    if (!realCommand) {
        return
    }

    // Run command
    realCommand.run(message, args)
})

// Time to login
client.login(token)